@@ -1,7 +1,7 @@
 /*
 **  OSSP str - String Handling
-**  Copyright (c) 1999-2003 Ralf S. Engelschall <rse@engelschall.com>
-**  Copyright (c) 1999-2003 The OSSP Project <http://www.ossp.org/>
+**  Copyright (c) 1999-2005 Ralf S. Engelschall <rse@engelschall.com>
+**  Copyright (c) 1999-2005 The OSSP Project <http://www.ossp.org/>
 **
 **  This file is part of OSSP str, a string handling and manipulation
 **  library which can be found at http://www.ossp.org/pkg/lib/str/.
@@ -89,6 +89,13 @@
  * on-the-fly.
  */
 
+#include <stdio.h>
+#include <stdlib.h>
+#include <stdarg.h>
+#include <string.h>
+#include <ctype.h>
+#include <math.h>
+
 #include "str_p.h"
 
 /* types which are locally use */
@@ -143,10 +150,10 @@ str_modf(
 {
     double fraction;
     double integral;
-    long trunc;
+    long truncated;
 
-    trunc = (long)arg;
-    integral = (double)trunc;
+    truncated = (long)arg;
+    integral = (double)truncated;
     fraction = arg - integral;
     if (iptr != NULL)
         *iptr = integral;
