@@ -32,7 +32,6 @@
 #include "lmtp2nntp_msg.h"
 #include "lmtp2nntp_argz.h"
 #include "lmtp2nntp_common.h" /* only required for logbook() */
-#include "tai.h"
 #include "str.h"
 
 /* third party */
@@ -243,7 +242,7 @@ msg_rc_t msg_join(msg_t *msg)
     size_t       asNewheaders;
 
     logbook(msg->l2, L2_LEVEL_DEBUG, "verify Newsgroups");
-    if (msg->azNewsgroups == NULL)
+    if ((msg->azNewsgroups == NULL) || (msg->asNewsgroups == 0))
         return MSG_ERR_JOINGROUPNONE;
     argz_stringify(msg->azNewsgroups, msg->asNewsgroups, ',');
     if (strlen(msg->azNewsgroups) == 0)
